@@ -2,7 +2,10 @@
 Tools for reading a nexus file
 """
 import re
-import io
+try:
+    import io
+except ImportError:
+    import StringIO as io
 
 DEBUG = False
 
@@ -172,12 +175,12 @@ class TreeHandler(GenericHandler):
         return "<NexusTreeBlock: %d trees>" % self.ntrees
 
 
-
 class DataHandler(GenericHandler):
     """Handler for data matrices"""
     def __init__(self):
         self.taxa = []
         self.ntaxa = 0
+        self.characters = {}
         self.nchar = 0
         self.format = {}
         self.gaps = None
@@ -259,8 +262,7 @@ class DataHandler(GenericHandler):
         if multistate:
             raise NexusFormatException("Data Matrix contains incomplete multistate values")
         return out
-
-
+    
     def parse(self, data):
         """
         Parses a `data` block
@@ -315,10 +317,19 @@ class DataHandler(GenericHandler):
 
                 self.matrix[taxon] = self.matrix.get(taxon, [])
                 self.matrix[taxon].extend(self._parse_sites(sites))
-
+                
+        self._load_characters()
+                
         if self.ntaxa is None:
             self.ntaxa = len(self.taxa)
-
+    
+    def _load_characters(self):
+        """Loads characters into self.characters section"""
+        for taxon in self.taxa:
+            for index, char in enumerate(self.matrix[taxon]):
+                self.characters[index] = self.characters.get(index, {})
+                self.characters[index][taxon] = self.matrix[taxon][index]
+    
     def write(self):
         """
         Generates a string containing a nexus data block.
@@ -334,8 +345,12 @@ class DataHandler(GenericHandler):
             """
             fstring = ['\tformat']
             for key, value in self.format.items():
-                if key == 'datatype': # Datatype must come first
+                if key == 'datatype':
+                    # Datatype must come first!
                     fstring.insert(1, "%s=%s" % (key, value))
+                elif key in ('interleave', ):
+                    # IGNORE the interleaving
+                    continue 
                 else:
                     if key == 'symbols':
                         value = '"%s"' % value
@@ -451,4 +466,17 @@ class NexusReader(object):
         out = ["#NEXUS\n"]
         for block in self.raw_blocks:
             out.append(self.blocks[block].write())
-        return "\n".join(out)
\ No newline at end of file
+        return "\n".join(out)
+        
+    def write_to_file(self, filename):
+        """
+        Writes the nexus to a file.
+        
+        :return: None
+        
+        :raises IOError: If file writing fails.
+        """
+        handle = open(filename, 'w')
+        handle.writelines(self.write())
+        handle.close()
+        
\ No newline at end of file
